@@ -103,12 +103,6 @@
 #' coordinates correspond to the rows of the matrix and vertical coordinates
 #' correspond to columns, and vertical coordinates are indexed in increasing
 #' order from bottom to top.
-#' For the argument \code{color}, an appropriate
-#' color palette for quantitative data is recommended,
-#' as outlined in the help page of
-#' the \code{\link[RColorBrewer:ColorBrewer]{brewer.pal}()} function of
-#' the
-#' \pkg{RColorBrewer} package.
 #' See the package vignette \code{LDheatmap} for more examples and details
 #' of the implementation. Examples of adding ``tracks'' of genomic
 #' annotation above a flipped heatmap are in the package vignette
@@ -196,7 +190,7 @@ plot_LDheatmap <- function (hap,
     if (inherits(hap, "hapResult")) {
         gdat <- data.frame(hap)
 
-        if(isFALSE(SNP.name)) SNP.name <- NULL else
+        if(base::isFALSE(SNP.name)) SNP.name <- NULL else
             if(isTRUE(SNP.name))
                 SNP.name <- t(hap[4, -c(1, ncol(hap))])[, 1]
 
