@@ -24,7 +24,32 @@ allS <- list(
     hetero = hetero,
     all = c(homo, hetero)
 )
-
+OPTS <- list(
+    labels = TRUE,
+    labels.cex = 1,
+    labels.font = 2,
+    link.color = "black",
+    link.type = 1,
+    link.type.alt = 2,
+    link.width = 1,
+    link.width.alt = 1,
+    haplotype.inner.color = "white",
+    haplotype.outer.color = "black",
+    mutations.cex = 1,
+    mutations.font = 1,
+    mutations.frame.background = "#0000FF4D",
+    mutations.frame.border = "black",
+    mutations.text.color = 1,
+    mutations.arrow.color = "black",
+    mutations.arrow.type = "triangle",
+    mutations.sequence.color = "#BFBFBF4D",
+    mutations.sequence.end = "round",
+    mutations.sequence.length = 0.3,
+    mutations.sequence.width = 5,
+    pie.inner.segments.color = "black",
+    pie.colors.function = rainbow,
+    scale.ratio = 1,
+    show.mutation = 2)
 
 # B: C G T
 # D: A G T
